@@ -12,14 +12,13 @@
 #include <fcntl.h>
 #include <linux/kd.h>
 #include <sys/ioctl.h>
+#include <malloc.h> /* just to be sure */
 #include "paths.h"
 
 /* the two exported functions */
 void saveunicodemap(int fd, char *oufil);
 void loadunicodemap(int fd, char *ufil);
 
-extern char *malloc(), *realloc();
-
 static char *unidirpath[] = { "", DATADIR "/" TRANSDIR "/", 0 };
 static char *unisuffixes[] = { "", ".uni", 0 };
 
