@@ -17,6 +17,7 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <sys/kd.h>
+#include <malloc.h> /* just to be sure */
 #include "paths.h"
 #include "psf.h"
 
@@ -30,7 +31,6 @@ extern void loadnewmap(int fd, char *mfil);
 extern void saveunicodemap(int fd, char *oufil);
 extern void loadunicodemap(int fd, char *ufil);
 extern void activatemap(void);
-extern char *malloc();
 
 /* search for the font in these directories (with trailing /) */
 char *fontdirpath[] = { "", DATADIR "/" FONTDIR "/", 0 };
