@@ -17,7 +17,8 @@ leave(n) int n; {
   exit(n);
 }
 
-int main (argc,argv) int argc; char **argv; {
+int
+main (argc,argv) int argc; char **argv; {
   unsigned char i, j, k;
 
   if (argc != 1) {
@@ -50,6 +51,7 @@ int main (argc,argv) int argc; char **argv; {
       exit(1);
   }
 
+  printf("\033%%@");		/* leave Unicode */
   printf("\033(K");		/* select user translation */
 
   /* show first half of font */
@@ -86,4 +88,6 @@ int main (argc,argv) int argc; char **argv; {
   printf("\033(B");		/* and return to usual translation */
 #endif
   leave(0);
+
+  exit(0);			/* make gcc happy */
 }
